==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/ImageStorageProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.ImageStorageProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a storage profile.
 * @property dataDisks Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
 * @property osDisk Specifies information about the operating system disk used by the virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
 * @property zoneResilient Specifies whether an image is zone resilient or not. Default is false. Zone resilient images can be created only in regions that provide Zone Redundant Storage (ZRS).
 */
public data class ImageStorageProfileArgs(
    public val dataDisks: Output<List<ImageDataDiskArgs>>? = null,
    public val osDisk: Output<ImageOSDiskArgs>? = null,
    public val zoneResilient: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.ImageStorageProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.ImageStorageProfileArgs =
        com.pulumi.azurenative.compute.inputs.ImageStorageProfileArgs.builder()
            .dataDisks(
                dataDisks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .osDisk(osDisk?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .zoneResilient(zoneResilient?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ImageStorageProfileArgs].
 */
@PulumiTagMarker
public class ImageStorageProfileArgsBuilder internal constructor() {
    private var dataDisks: Output<List<ImageDataDiskArgs>>? = null

    private var osDisk: Output<ImageOSDiskArgs>? = null

    private var zoneResilient: Output<Boolean>? = null

    /**
     * @param value Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("psragoxiljedhuaj")
    public suspend fun dataDisks(`value`: Output<List<ImageDataDiskArgs>>) {
        this.dataDisks = value
    }

    @JvmName("fuciqcxratoqqitf")
    public suspend fun dataDisks(vararg values: Output<ImageDataDiskArgs>) {
        this.dataDisks = Output.all(values.asList())
    }

    /**
     * @param values Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("mqmiaixrwkibldly")
    public suspend fun dataDisks(values: List<Output<ImageDataDiskArgs>>) {
        this.dataDisks = Output.all(values)
    }

    /**
     * @param value Specifies information about the operating system disk used by the virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("wlbqvnphfemquxqf")
    public suspend fun osDisk(`value`: Output<ImageOSDiskArgs>) {
        this.osDisk = value
    }

    /**
     * @param value Specifies whether an image is zone resilient or not. Default is false. Zone resilient images can be created only in regions that provide Zone Redundant Storage (ZRS).
     */
    @JvmName("jokxlchtsmgiuxjc")
    public suspend fun zoneResilient(`value`: Output<Boolean>) {
        this.zoneResilient = value
    }

    /**
     * @param value Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("cpffsomfdwpxotwn")
    public suspend fun dataDisks(`value`: List<ImageDataDiskArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataDisks = mapped
    }

    /**
     * @param argument Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("ijsosrewwdqwteha")
    public suspend fun dataDisks(argument: List<suspend ImageDataDiskArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ImageDataDiskArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDisks = mapped
    }

    /**
     * @param argument Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("mvgtydxmaenyjsmu")
    public suspend fun dataDisks(vararg argument: suspend ImageDataDiskArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ImageDataDiskArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDisks = mapped
    }

    /**
     * @param argument Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("cxlxamfenaupumwu")
    public suspend fun dataDisks(argument: suspend ImageDataDiskArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ImageDataDiskArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dataDisks = mapped
    }

    /**
     * @param values Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("ooblaaocibbqqlwd")
    public suspend fun dataDisks(vararg values: ImageDataDiskArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataDisks = mapped
    }

    /**
     * @param value Specifies information about the operating system disk used by the virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("pyrolhcpymyyfvbf")
    public suspend fun osDisk(`value`: ImageOSDiskArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.osDisk = mapped
    }

    /**
     * @param argument Specifies information about the operating system disk used by the virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("orkrapwcqdyfppdv")
    public suspend fun osDisk(argument: suspend ImageOSDiskArgsBuilder.() -> Unit) {
        val toBeMapped = ImageOSDiskArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.osDisk = mapped
    }

    /**
     * @param value Specifies whether an image is zone resilient or not. Default is false. Zone resilient images can be created only in regions that provide Zone Redundant Storage (ZRS).
     */
    @JvmName("hhdmjyfqwduosugd")
    public suspend fun zoneResilient(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zoneResilient = mapped
    }

    internal fun build(): ImageStorageProfileArgs = ImageStorageProfileArgs(
        dataDisks = dataDisks,
        osDisk = osDisk,
        zoneResilient = zoneResilient,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/ImageStorageProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.ImageStorageProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a storage profile.
 * @property dataDisks Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
 * @property osDisk Specifies information about the operating system disk used by the virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
 * @property zoneResilient Specifies whether an image is zone resilient or not. Default is false. Zone resilient images can be created only in regions that provide Zone Redundant Storage (ZRS).
 */
public data class ImageStorageProfileArgs(
    public val dataDisks: Output<List<ImageDataDiskArgs>>? = null,
    public val osDisk: Output<ImageOSDiskArgs>? = null,
    public val zoneResilient: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.ImageStorageProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.ImageStorageProfileArgs =
        com.pulumi.azurenative.compute.inputs.ImageStorageProfileArgs.builder()
            .dataDisks(
                dataDisks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .osDisk(osDisk?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .zoneResilient(zoneResilient?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ImageStorageProfileArgs].
 */
@PulumiTagMarker
public class ImageStorageProfileArgsBuilder internal constructor() {
    private var dataDisks: Output<List<ImageDataDiskArgs>>? = null

    private var osDisk: Output<ImageOSDiskArgs>? = null

    private var zoneResilient: Output<Boolean>? = null

    /**
     * @param value Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("stpfrgxrybncvunk")
    public suspend fun dataDisks(`value`: Output<List<ImageDataDiskArgs>>) {
        this.dataDisks = value
    }

    @JvmName("lwvtklurrxxfxbyf")
    public suspend fun dataDisks(vararg values: Output<ImageDataDiskArgs>) {
        this.dataDisks = Output.all(values.asList())
    }

    /**
     * @param values Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("kgykxyiphwsyvgeu")
    public suspend fun dataDisks(values: List<Output<ImageDataDiskArgs>>) {
        this.dataDisks = Output.all(values)
    }

    /**
     * @param value Specifies information about the operating system disk used by the virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("gtdqmbcqoouwcssy")
    public suspend fun osDisk(`value`: Output<ImageOSDiskArgs>) {
        this.osDisk = value
    }

    /**
     * @param value Specifies whether an image is zone resilient or not. Default is false. Zone resilient images can be created only in regions that provide Zone Redundant Storage (ZRS).
     */
    @JvmName("gqbnuwetxdufyoti")
    public suspend fun zoneResilient(`value`: Output<Boolean>) {
        this.zoneResilient = value
    }

    /**
     * @param value Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("xmxelslkgaiivueu")
    public suspend fun dataDisks(`value`: List<ImageDataDiskArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataDisks = mapped
    }

    /**
     * @param argument Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("rmokkygpkmrmmfvb")
    public suspend fun dataDisks(argument: List<suspend ImageDataDiskArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ImageDataDiskArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDisks = mapped
    }

    /**
     * @param argument Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("luowgocruqqvdusk")
    public suspend fun dataDisks(vararg argument: suspend ImageDataDiskArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ImageDataDiskArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDisks = mapped
    }

    /**
     * @param argument Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("fmfnwrlfnrfqiuel")
    public suspend fun dataDisks(argument: suspend ImageDataDiskArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ImageDataDiskArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dataDisks = mapped
    }

    /**
     * @param values Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("bbxnyfdykljqwqug")
    public suspend fun dataDisks(vararg values: ImageDataDiskArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataDisks = mapped
    }

    /**
     * @param value Specifies information about the operating system disk used by the virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("trlcqgtfbpwscklg")
    public suspend fun osDisk(`value`: ImageOSDiskArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.osDisk = mapped
    }

    /**
     * @param argument Specifies information about the operating system disk used by the virtual machine. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual machines](https://docs.microsoft.com/azure/virtual-machines/managed-disks-overview).
     */
    @JvmName("imtohpdivychqhdu")
    public suspend fun osDisk(argument: suspend ImageOSDiskArgsBuilder.() -> Unit) {
        val toBeMapped = ImageOSDiskArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.osDisk = mapped
    }

    /**
     * @param value Specifies whether an image is zone resilient or not. Default is false. Zone resilient images can be created only in regions that provide Zone Redundant Storage (ZRS).
     */
    @JvmName("lqinipqggclyrqrj")
    public suspend fun zoneResilient(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zoneResilient = mapped
    }

    internal fun build(): ImageStorageProfileArgs = ImageStorageProfileArgs(
        dataDisks = dataDisks,
        osDisk = osDisk,
        zoneResilient = zoneResilient,
    )
}
